summaryrefslogtreecommitdiff
path: root/test/unit/theory/union_find_black.h
diff options
context:
space:
mode:
Diffstat (limited to 'test/unit/theory/union_find_black.h')
-rw-r--r--test/unit/theory/union_find_black.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/test/unit/theory/union_find_black.h b/test/unit/theory/union_find_black.h
index 6ba653946..fead619d2 100644
--- a/test/unit/theory/union_find_black.h
+++ b/test/unit/theory/union_find_black.h
@@ -5,25 +5,25 @@
** Major contributors: none
** Minor contributors (to current version): none
** This file is part of the CVC4 prototype.
- ** Copyright (c) 2009, 2010 The Analysis of Computer Systems Group (ACSys)
+ ** Copyright (c) 2009, 2010, 2011 The Analysis of Computer Systems Group (ACSys)
** Courant Institute of Mathematical Sciences
** New York University
** See the file COPYING in the top-level source directory for licensing
** information.\endverbatim
**
** \brief Black box testing of CVC4::theory::uf::morgan::UnionFind
**
** Black box testing of CVC4::theory::uf::morgan::UnionFind.
**/
#include <cxxtest/TestSuite.h>
#include "context/context.h"
#include "expr/node.h"
-#include "theory/uf/morgan/union_find.h"
+#include "theory/datatypes/union_find.h"
using namespace CVC4;
-using namespace CVC4::theory::uf::morgan;
+using namespace CVC4::theory::datatypes;
using namespace CVC4::context;
using namespace std;
generated by cgit on debian on lair
@@ -5,25 +5,25 @@
** information.\endverbatim
**
- ** \brief Black box testing of CVC4::theory::uf::morgan::UnionFind
+ ** \brief Black box testing of CVC4::datatypes::UnionFind
**
@@ -5,25 +5,25 @@
**
- ** Black box testing of CVC4::theory::uf::morgan::UnionFind.
+ ** Black box testing of CVC4::theory::datatypes::UnionFind.
**/
#include <cxxtest/TestSuite.h>
contact matthew@masot.net with questions or feedback